@@ -178,3 +178,6 @@ Selected <- NULL
 
 thresh <- NULL
 
+probValues <- min_prob <- NULL
+
+altTrainWorkflow <- function(x) x
\ No newline at end of file
