@@ -1,4 +1,21 @@
 
+contr.ltfr <- function (n, contrasts = TRUE, sparse = FALSE) 
+{
+  if (is.numeric(n) && length(n) == 1L) {
+    if (n > 1L) 
+      levels <- as.character(seq_len(n))
+    else stop("not enough degrees of freedom to define contrasts")
+  }
+  else {
+    levels <- as.character(n)
+    n <- length(n)
+  }
+  contr <- stats:::.Diag(levels, sparse = sparse)
+  if (contrasts) {
+    if (n < 2L) stop(gettextf("contrasts not defined for %d degrees of freedom", n - 1L), domain = NA)
+  }
+  contr
+}
 
 contr.dummy <- function(n, ...)
   {
@@ -22,7 +39,7 @@ contr.dummy <- function(n, ...)
   function(formula, ...){
     UseMethod("dummyVars")
   }
-dummyVars.default <- function (formula, data, sep = ".", levelsOnly = FALSE, ...) 
+dummyVars.default <- function (formula, data, sep = ".", levelsOnly = FALSE, fullRank = FALSE, ...) 
 {
   formula <- as.formula(formula)
   if(!is.data.frame(data)) data <- as.data.frame(data)
@@ -38,6 +55,17 @@ dummyVars.default <- function (formula, data, sep = ".", levelsOnly = FALSE, ...
     {
       facVars <- vars[isFac] 
       lvls <- lapply(data[,facVars,drop = FALSE], levels)
+      if(levelsOnly)
+      {
+        tabs <- table(unlist(lvls))
+        if(any(tabs > 1))
+        {
+          stop(paste("You requested `levelsOnly = TRUE` but",
+                     "the following levels are not unique",
+                     "across predictors:",
+                     paste(names(tabs)[tabs > 1], collapse = ", ")))
+        }
+      }
     } else {
       facVars <- NULL
       lvls <- NULL
@@ -50,7 +78,8 @@ dummyVars.default <- function (formula, data, sep = ".", levelsOnly = FALSE, ...
               lvls = lvls,
               sep = sep,
               terms = trms,
-              levelsOnly = levelsOnly)
+              levelsOnly = levelsOnly,
+              fullRank = fullRank)
   class(out) <- "dummyVars"
   out
 
@@ -66,6 +95,7 @@ print.dummyVars <- function(x, ...)
     if(!is.null(x$sep) & !x$levelsOnly) cat("Variables and levels will be separated by '",
                                             x$sep, "'\n", sep = "")
     if(x$levelsOnly) cat("Factor variable names will be removed\n")
+    if(x$fullRank) cat("A full rank encoding is used") else cat("A less than full rank encoding is used") 
     cat("\n")
     invisible(x)
   }
@@ -83,15 +113,18 @@ predict.dummyVars <- function(object, newdata, na.action = na.pass, ...)
                                                          "are not in newdata"))
     Terms <- object$terms
     Terms <- delete.response(Terms)
-    oldContr <- options("contrasts")$contrasts
-    newContr <- oldContr
-    newContr["unordered"] <- "contr.dummy"
-    options(contrasts = newContr)
+    if(!object$fullRank)
+    {
+      oldContr <- options("contrasts")$contrasts
+      newContr <- oldContr
+      newContr["unordered"] <- "contr.ltfr"
+      options(contrasts = newContr)
+    }
     m <- model.frame(Terms, newdata, na.action = na.action, xlev = object$xlevels)
 
     x <- model.matrix(Terms, m)
-    options(contrasts = oldContr)
-    x[is.na(x)] <- 1
+    if(!object$fullRank) options(contrasts = oldContr)
+
     if(object$levelsOnly)
       {
         for(i in object$facVars)
@@ -108,7 +141,7 @@ predict.dummyVars <- function(object, newdata, na.action = na.pass, ...)
             colnames(x) <- gsub(paste(":", i, sep = ""), paste(":", i, object$sep, sep = ""), colnames(x), fixed = TRUE)
           }
       }  
-    x[, -1]
+    x[, colnames(x) != "(Intercept)", drop = FALSE]
   }
 
 
